.. _time_concept:

=====================================
Thinking about Time in the Simulation
=====================================

.. contents::
   :depth: 2
   :local:
   :backlinks: none

Outline
-------
 - The simulation clock
 - Start, stop, and step size.
 - Fundamental assumptions about discrete time simulation.
 - builder.time.clock().clock() vs. event.time
